==> itp_1.0.0.tar.gz: itp/tests/testthat/test-continuous.R <==
# Check that for some continuous example functions that
# (a) (b-a) / 2 is no larger than epsilon
# (b) f(root) is close to zero

epsilon <- 1e-10

# The example used in the Wikipedia entry for the ITP method
wiki <- function(x) x ^ 3 - x - 2
res <- itp(wiki, c(1, 2), k1 = 0.1, n0 = 1, epsilon = epsilon)
test_that("Wiki cubic: tolerance", {
  testthat::expect_lte(res$b - res$a , 2 * epsilon)
})
test_that("Wiki cubic: f approx 0", {
  testthat::expect_equal(res$f.root, 0)
})

# Lambert

lambert <- function(x) x * exp(x) - 1
res <- itp(lambert, c(-1, 1), epsilon = epsilon)
test_that("Lambert: tolerance", {
  testthat::expect_lte(res$b - res$a , 2 * epsilon)
})
test_that("Lambert: f approx 0", {
  testthat::expect_equal(res$f.root, 0)
})

# Polynomial 3
poly3 <- function(x) (x * 1e6 - 1) ^ 3
res <- itp(poly3, c(-1, 1), epsilon = epsilon)
test_that("Polynomial 3: tolerance", {
  testthat::expect_lte(res$b - res$a , 2 * epsilon)
})
test_that("Polynomial 3: f approx 0", {
  testthat::expect_equal(res$f.root, 0)
})

# Linear

linear <- function(x) x
res <- itp(linear, c(-1, 1), epsilon = epsilon)
test_that("Linear: tolerance", {
  testthat::expect_lte(res$b - res$a , 2 * epsilon)
})
test_that("Linear: f approx 0", {
  testthat::expect_equal(res$f.root, 0)
})

# Linear, solution at an input endpoint
res <- itp(linear, c(-1, 0))
test_that("Linear: solution at a", {
  testthat::expect_equal(c(res$iter, res$root, res$f.root), c(0, 0, 0))
})
res <- itp(linear, c(0, 1))
test_that("Linear: solution at b", {
  testthat::expect_equal(c(res$iter, res$root, res$f.root), c(0, 0, 0))
})

==> itp_1.0.1.tar.gz: itp/tests/testthat/test-continuous.R <==
# Check that for some continuous example functions that
# (a) (b-a) / 2 is no larger than epsilon
# (b) f(root) is close to zero

epsilon <- 1e-10

# The example used in the Wikipedia entry for the ITP method
wiki <- function(x) x ^ 3 - x - 2
res <- itp(wiki, c(1, 2), k1 = 0.1, n0 = 1, epsilon = epsilon)
test_that("Wiki cubic: tolerance", {
  testthat::expect_lte(res$b - res$a , 2 * epsilon)
})
test_that("Wiki cubic: f approx 0", {
  testthat::expect_equal(res$f.root, 0)
})
# Repeat for -wiki, to check for a locally decreasing function
neg_wiki <- function(x) -wiki(x)
res <- itp(neg_wiki, c(1, 2), k1 = 0.1, n0 = 1, epsilon = epsilon)
test_that("-Wiki cubic: tolerance", {
  testthat::expect_lte(res$b - res$a , 2 * epsilon)
})
test_that("-Wiki cubic: f approx 0", {
  testthat::expect_equal(res$f.root, 0)
})

# Lambert

lambert <- function(x) x * exp(x) - 1
res <- itp(lambert, c(-1, 1), epsilon = epsilon)
test_that("Lambert: tolerance", {
  testthat::expect_lte(res$b - res$a , 2 * epsilon)
})
test_that("Lambert: f approx 0", {
  testthat::expect_equal(res$f.root, 0)
})
# Repeat for -lambert
neg_lambert <- function(x) -lambert(x)
res <- itp(neg_lambert, c(-1, 1), epsilon = epsilon)
test_that("-Lambert: tolerance", {
  testthat::expect_lte(res$b - res$a , 2 * epsilon)
})
test_that("-Lambert: f approx 0", {
  testthat::expect_equal(res$f.root, 0)
})

# Polynomial 3
poly3 <- function(x) (x * 1e6 - 1) ^ 3
res <- itp(poly3, c(-1, 1), epsilon = epsilon)
test_that("Polynomial 3: tolerance", {
  testthat::expect_lte(res$b - res$a , 2 * epsilon)
})
test_that("Polynomial 3: f approx 0", {
  testthat::expect_equal(res$f.root, 0)
})
# Repeat for -poly3
neg_poly3 <- function(x) -poly3(x)
res <- itp(neg_poly3, c(-1, 1), epsilon = epsilon)
test_that("-Polynomial 3: tolerance", {
  testthat::expect_lte(res$b - res$a , 2 * epsilon)
})
test_that("-Polynomial 3: f approx 0", {
  testthat::expect_equal(res$f.root, 0)
})

# Logarithmic
logarithmic <- function(x) log(abs(x - 10 / 9))
res <- itp(logarithmic, c(-1, 1), epsilon = epsilon)
test_that("Logarithmic: tolerance", {
  testthat::expect_lte(res$b - res$a , 2 * epsilon)
})
test_that("Logarithmic: f approx 0", {
  testthat::expect_equal(res$f.root, 0)
})

# Linear

linear <- function(x) x
res <- itp(linear, c(-1, 1), epsilon = epsilon)
test_that("Linear: tolerance", {
  testthat::expect_lte(res$b - res$a , 2 * epsilon)
})
test_that("Linear: f approx 0", {
  testthat::expect_equal(res$f.root, 0)
})
# Repeat for -linear
neg_linear <- function(x) -linear(x)
res <- itp(neg_linear, c(-1, 1), epsilon = epsilon)
test_that("-Linear: tolerance", {
  testthat::expect_lte(res$b - res$a , 2 * epsilon)
})
test_that("-Linear: f approx 0", {
  testthat::expect_equal(res$f.root, 0)
})

# Linear, solution at an input endpoint
res <- itp(linear, c(-1, 0))
test_that("Linear: solution at a", {
  testthat::expect_equal(c(res$iter, res$root, res$f.root), c(0, 0, 0))
})
res <- itp(linear, c(0, 1))
test_that("Linear: solution at b", {
  testthat::expect_equal(c(res$iter, res$root, res$f.root), c(0, 0, 0))
})
